Module deceptive_canary

Module deceptive_canary 

Deceptive-canary endpoint configuration types (#555 phase 6 — moved out of mockforge-core because its only callers are the (still in http) middleware + the deceptive_canary HTTP handler, and keeping the module here lets the eventual handler move follow). Self-contained. Deceptive Canary Mode

Routes a small percentage of team traffic to “deceptive deploys” by default, with opt-out. Great for dogfooding realism in cloud deployments.

Structs

CanaryStats
Statistics for canary routing
DeceptiveCanaryConfig
Deceptive canary configuration
DeceptiveCanaryRouter
Deceptive canary router
TeamIdentifiers
Team/user identification criteria

Enums

CanaryRoutingStrategy
Canary routing strategy